#
# spec file for package labwc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     warp
%bcond_with     xwayland
%define sname   wlroots
%define sver    0.17.0
Name:           labwc
Version:        0.7.0
Release:        1.2
Summary:        A Wayland window-stacking compositor
License:        GPL-2.0-or-later
URL:            https://github.com/labwc/labwc
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
%if %{with warp}
Source1:        https://gitlab.freedesktop.org/wlroots/wlroots/-/archive/%{sver}/%{sname}-%{sver}.tar.bz2
Provides:       bundled(wlroots)
BuildRequires:  glslang-devel
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(hwdata)
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libliftoff)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xwaylandproto)
%else
BuildRequires:  wlroots-devel
%endif
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libinput) >= 1.14
BuildRequires:  pkgconfig(librsvg-2.0) 
BuildRequires:  pkgconfig(libseat) 
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  scdoc
Recommends:     xwayland
Recommends:     %{name}-lang
Requires:       foot
Suggests:       rofi-wayland
Suggests:       grim
Suggests:       swaybg
Suggests:       waybar

%description
Labwc is a wlroots-based window-stacking compositor for wayland, inspired
by openbox.

%lang_package

%prep
%autosetup
sed -i "s/alacritty/foot/" docs/menu.xml

%if %{with warp}
mkdir subprojects/%{sname}
tar -xf %{SOURCE1} --strip-components 1 -C subprojects/%{sname}
%endif

%build
%meson \
    -Dman-pages=enabled \
%if %{with xwayland}
    -Dxwayland=enabled \
%else
    -Dxwayland=disabled \
%endif
    -Dnls=enabled
%meson_build

%install
%meson_install --skip-subprojects
install -Dm 0644 docs/*.xml -t %{buildroot}%{_sysconfdir}/xdg/%{name}/

%find_lang %{name}

%files
%license LICENSE
%doc NEWS.md README.md
%{_bindir}/%{name}
%dir %{_sysconfdir}/xdg/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/menu.xml
%config(noreplace) %{_sysconfdir}/xdg/%{name}/rc.xml
%dir %{_datadir}/wayland-sessions
%{_datadir}/wayland-sessions/%{name}.desktop
%{_mandir}/man?/%{name}*.?%{?ext_man}
%{_datadir}/doc/%{name}/

%files lang -f %{name}.lang

%changelog
* Thu Jan 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Remove openbox themes that cause conflict.
* Thu Jan 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- update to version 0.7.0
  + The main effort in this release has gone into porting labwc to
    wlroots 0.17 and tidying up regressions. Nonetheless, it
    contains a significant number of additions and fixes as
    described below. Should bug fixes be required against 0.6.6
    (built with wlroots 0.16), a 0.6 branch will be created.
  + Additions:
  - Support titlebar hover icons. Written-by: @spl237
  - Add theme options osd.workspace-switcher.boxes.{width,height}
    Written-by: @kyak
  - Add actions VirtualOutputAdd and VirtualOutputRemove to con-
    trol virtual outputs. Written-by: @kyak (gh#labwc/labwc#1287)
  - Teach MoveToEdge to move windows to adjacent outputs.
    Written-by: @ahesford
  - Implement <font place="InactiveWindow">. Written-by: @ludg1e
    (gh#labwc/labwc#1292)
  - Implement cursor-shape-v1 protocol to allow Wayland clients
    to request a buffer for a cursor shape from a compositor.
    Written-by: @heroin-moose
  - Implement fractional-scale-v1 protocol to allow Wayland
    clients to properly scale on outputs with fractional scale
    factor. Written-by: @heroin-moose
  - Add ResizeTo action (gh#labwc/labwc#1261)
  - Allow going backwards in window-switcher OSD by using
    arrow-up or arrow-left. Written-by: @jp7677
  - Add ToggleOmnipresent action and add an "Always on Visible
    Workspace" entry for it in the client-menu under the
    Workspaces submenu. Written-by: @bnason
  - Account for space taken up by XWayland clients with
    _NET_WM_STRUT_PARTIAL property in the usable_area
    calculation. This increases inter-operability with X11
    desktop componenets.
  - Set XWayland's _NET_WORKAREA property based on usable area.
    XWayland clients use the _NET_WORKAREA root window property
    to determine how much of the screen is not covered by
    panels/docks. The property is used for example by Qt to
    determine areas of the screen that popup menus should not
    overlap.
  + Fixed:
  - Fix xwayland.c null pointer dereference causing crash with
    CLions. (gh#labwc/labwc#1352)
  - Fix issue with XWayland surfaces completely offscreen not
    generating commit events and therefore preventing them from
    moving onscreen.
  - Do not de-active windows when layer-shell client takes
    keyboard focus, to fix sfwbar minimize action.
    (gh#labwc/labwc#1342)
  - Move layer-shell popups from the background layer to the
    top layer to render them above normal windows. Previously
    this was only done for the bottom layer. In support of
    Raspberry Pi's pcmanfm --desktop. (gh#labwc/labwc#1293)
  - Calculate usable_area before positioning clients to ensure it
    is correct before non exclusive-zone layer-shell clients are
    positioned or resized. (gh#labwc/labwc#1285)
  - Prevent overriding XWayland maximized/fullscreen/tiled
    geometry to fix an issue where some XWayland views (example:
    xfce4-terminal) do not end up with exactly the correct
    geometry when tiled.
  + Changed:
  - Treat XWayland panel windows as if fixedPosition rule is set
  - Use the GTK3 notebook header color as the default active
    title color (small change from #dddad6 to #e1dedb).
    Written-by: @dimkr
* Wed Apr 12 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- update to version 0.6.2
* Sat Nov 19 2022 Андрей Алыпов <and.november@opensuse.org>
- update to version 0.6.0
* Sun Mar  7 2021 Андрей Алыпов <and.november@opensuse.org>
- initial package (version 0.1.0) for openSUSE
